@@ -31,9 +31,9 @@ speeding up such operation.
 
 Some improvement and bug fixes available in newer version of Mercurial are also
 backported to older version of Mercurial by this extension. Some older
-experimental protocol are also supported for a longer time in the extensions to
-help people transitioning. (The extensions is currently compatible down to
-Mercurial version 4.6).
+experimental protocols are also supported for a longer time in the extension to
+help people transitioning. (The extension is currently compatible down to
+Mercurial version 4.7).
 
 New Config::
 
@@ -90,13 +90,10 @@ the experiment. It is shipped with Mercurial so no extra install is needed::
     [extensions]
     blackbox =
 
-Finally some extra options are available to help tame the experimental
+Finally one more option is available to help tame the experimental
 implementation of some of the algorithms::
 
     [experimental]
-    # restrict cache size to reduce memory consumption
-    obshashrange.lru-size = 2000 # default is 2000
-
     # automatically disable obshashrange related computation and capabilities
     # if the repository has more than N revisions.  This is meant to help large
     # server deployment to enable the feature on smaller repositories while
@@ -819,7 +816,8 @@ def cmdprevious(ui, repo, **opts):
      (b'', b'evolve', True, _(b'evolve the next changeset if necessary')),
      (b'', b'no-topic', False, _(b'ignore topic and move topologically')),
      (b'n', b'dry-run', False,
-      _(b'do not perform actions, just print what would be done'))],
+      _(b'do not perform actions, just print what would be done')),
+     (b'', b'abort', False, _(b'abort the interrupted next'))],
     b'[OPTION]...',
     helpbasic=True,
     **compat.helpcategorykwargs('CATEGORY_WORKING_DIRECTORY'))
@@ -833,6 +831,26 @@ def cmdnext(ui, repo, **opts):
     """
     wlock = None
     dryrunopt = opts['dry_run']
+    abortopt = opts['abort']
+
+    compat.check_incompatible_arguments(opts, 'abort', ['move_bookmark', 'merge'])
+    if abortopt:
+        evolvestate = state.cmdstate(repo)
+        if not evolvestate:
+            raise error.Abort(_(b'no interrupted next to abort'))
+
+        evolvestate.load()
+        if evolvestate[b'command'] != b'next':
+            raise error.Abort(_(b'no interrupted next to abort'))
+
+        pctx = repo[b'.']
+        compat.clean_update(pctx)
+        ui.status(_(b'next aborted\n'))
+        ui.status(_(b'working directory is now at %s\n')
+                  % ui.label(bytes(pctx), b'evolve.node'))
+        evolvestate.delete()
+        return 0
+
     if not dryrunopt:
         wlock = repo.wlock()
     try:
