@@ -1011,7 +1011,7 @@ def cmdprune(ui, repo, *revs, **opts):
 
                 # reset files that only changed in the dirstate too
                 dirstate = repo.dirstate
-                dirchanges = [f for f in dirstate if dirstate[f] != b'n']
+                dirchanges = compat.dirchanges(dirstate)
                 changedfiles.extend(dirchanges)
                 repo.dirstate.rebuild(newnode.node(), newnode.manifest(),
                                       changedfiles)
@@ -1124,7 +1124,8 @@ def cmdsplit(ui, repo, *pats, **opts):
         bmupdate = rewriteutil.bookmarksupdater(repo, ctx.node(), tr)
         bookactive = repo._activebookmark
         if bookactive is not None:
-            repo.ui.status(_(b"(leaving bookmark %s)\n") % repo._activebookmark)
+            b = ui.label(repo._activebookmark, b'bookmarks')
+            ui.status(_(b"(leaving bookmark %s)\n") % b)
         bookmarksmod.deactivate(repo)
 
         # Prepare the working directory
@@ -1222,7 +1223,7 @@ def cmdsplit(ui, repo, *pats, **opts):
                     continue
                 break # propagate the previous break
             else:
-                ui.status(_(b"no more change to split\n"))
+                ui.status(_(b"no more changes to split\n"))
                 if haschanges():
                     # XXX: Should we show a message for informing the user
                     # that we create another commit with remaining changes?
@@ -1356,7 +1357,20 @@ def cmdpick(ui, repo, *revs, **opts):
         pickstate = state.cmdstate(repo, path=b'pickstate')
         pctx = repo[b'.']
 
-        if not cont and not abort:
+        if cont:
+            if revs:
+                raise error.Abort(_(b"cannot specify both --continue and "
+                                    b"revision"))
+            if not pickstate:
+                raise error.Abort(_(b"no interrupted pick state exists"))
+
+            pickstate.load()
+            orignode = pickstate[b'orignode']
+            origctx = repo[orignode]
+
+        elif abort:
+            return abortpick(ui, repo, pickstate)
+        else:
             cmdutil.bailifchanged(repo)
             revs = scmutil.revrange(repo, revs)
             if len(revs) > 1:
@@ -1384,21 +1398,6 @@ def cmdpick(ui, repo, *revs, **opts):
                 pickstate.save()
                 raise error.InterventionRequired(_(b"unresolved merge conflicts"
                                                    b" (see hg help resolve)"))
-
-        elif abort:
-            return abortpick(ui, repo, pickstate)
-
-        else:
-            if revs:
-                raise error.Abort(_(b"cannot specify both --continue and "
-                                    b"revision"))
-            if not pickstate:
-                raise error.Abort(_(b"no interrupted pick state exists"))
-
-            pickstate.load()
-            orignode = pickstate[b'orignode']
-            origctx = repo[orignode]
-
         overrides = {(b'phases', b'new-commit'): origctx.phase()}
         with repo.ui.configoverride(overrides, b'pick'):
             newnode = repo.commit(text=origctx.description(),
