@@ -87,15 +87,14 @@ from mercurial import (
     node as nodemod,
     registrar,
     scmutil,
-    ui as uimod,
     util,
 )
 
 from mercurial.i18n import _
 
 __version__ = b'0.1.3.dev'
-testedwith = b'4.6.2 4.7 4.8 4.9 5.0 5.1 5.2 5.3 5.4 5.5'
-minimumhgversion = b'4.6'
+testedwith = b'4.7 4.8 4.9 5.0 5.1 5.2 5.3 5.4 5.5 5.6 5.7 5.8 5.9'
+minimumhgversion = b'4.7'
 buglink = b'https://bz.mercurial-scm.org/'
 
 cmdtable = {}
@@ -513,10 +512,11 @@ def debugpullbundlecacheoverlap(ui, repo, *revs, **opts):
 
     repo.ui.write(b"gathering %d sample pulls within %d revisions\n"
                   % (count, len(actionrevs)))
+    progress = repo.ui.makeprogress(b'gathering data', b'pulls', count)
     if 1 < min_cache:
         repo.ui.write(b"  not caching ranges smaller than %d changesets\n" % min_cache)
     for i in range(count):
-        progress(repo.ui, b'gathering data', i, total=count)
+        progress.update(i)
         outgoing = takeonesample(repo, actionrevs)
         ranges = sliceoutgoing(repo, outgoing)
         hitranges = 0
@@ -540,7 +540,7 @@ def debugpullbundlecacheoverlap(ui, repo, *revs, **opts):
                  hitranges,
                  )
         pullstats.append(stats)
-    progress(repo.ui, b'gathering data', None)
+    progress.complete()
 
     sizes = []
     changesmissing = []
@@ -634,18 +634,6 @@ def fmtdist(name, data):
     data[b'name'] = name
     return STATSFORMAT % data
 
-# hg <= 4.6 (bec1212eceaa)
-if util.safehasattr(uimod.ui, 'makeprogress'):
-    def progress(ui, topic, pos, item=b"", unit=b"", total=None):
-        progress = ui.makeprogress(topic, unit, total)
-        if pos is not None:
-            progress.update(pos, item=item)
-        else:
-            progress.complete()
-else:
-    def progress(ui, topic, pos, item=b"", unit=b"", total=None):
-        ui.progress(topic, pos, item, unit, total)
-
 # nodemap.get and index.[has_node|rev|get_rev]
 # hg <= 5.2 (02802fa87b74)
 def getgetrev(cl):
