@@ -229,13 +229,12 @@ colortable = {b'topic.active': b'green',
               # default color to help log output and thg
               # (first pick I could think off, update as needed
               b'log.topic': b'green_background',
-              b'topic.active': b'green',
               }
 
-__version__ = b'0.22.3'
+__version__ = b'0.23.0'
 
-testedwith = b'4.6.2 4.7 4.8 4.9 5.0 5.1 5.2 5.3 5.4 5.5 5.6 5.7 5.8 5.9'
-minimumhgversion = b'4.6'
+testedwith = b'4.7 4.8 4.9 5.0 5.1 5.2 5.3 5.4 5.5 5.6 5.7 5.8 5.9'
+minimumhgversion = b'4.7'
 buglink = b'https://bz.mercurial-scm.org/'
 
 if util.safehasattr(registrar, 'configitem'):
@@ -298,6 +297,9 @@ def _contexttopic(self, force=False):
     # topic loaded, but not enabled (eg: multiple repo in the same process)
     if cache is None:
         return b''
+    if self.rev() is None:
+        # don't cache volatile ctx instances that aren't stored on-disk yet
+        return self.extra().get(constants.extrakey, b'')
     topic = cache.get(self.rev())
     if topic is None:
         topic = self.extra().get(constants.extrakey, b'')
@@ -485,21 +487,10 @@ def reposetup(ui, repo):
                 return super(topicrepo, self).commit(*args, **kwargs)
 
         def commitctx(self, ctx, *args, **kwargs):
-            topicfilter = topicmap.topicfilter(self.filtername)
-            if topicfilter != self.filtername:
-                other = self.filtered(topicmap.topicfilter(self.filtername))
-                other.commitctx(ctx, *args, **kwargs)
-
             if isinstance(ctx, context.workingcommitctx):
                 current = self.currenttopic
                 if current:
                     ctx.extra()[constants.extrakey] = current
-            if (isinstance(ctx, context.memctx)
-                and ctx.extra().get(b'amend_source')
-                and ctx.topic()
-                and not self.currenttopic):
-                # we are amending and need to remove a topic
-                del ctx.extra()[constants.extrakey]
             return super(topicrepo, self).commitctx(ctx, *args, **kwargs)
 
         @util.propertycache
@@ -670,7 +661,8 @@ def reposetup(ui, repo):
                 csetcount = stack.stack(repo, topic=ct).changesetcount
                 empty = csetcount == 0
                 if empty and not ctwasempty:
-                    ui.status(b"active topic '%s' is now empty\n" % ct)
+                    ui.status(b"active topic '%s' is now empty\n"
+                              % ui.label(ct, b'topic.active'))
                     trnames = getattr(tr, 'names', getattr(tr, '_names', ()))
                     if (b'phase' in trnames
                             or any(n.startswith(b'push-response')
@@ -680,10 +672,10 @@ def reposetup(ui, repo):
                 if ctwasempty and not empty:
                     if csetcount == 1:
                         msg = _(b"active topic '%s' grew its first changeset\n%s")
-                        ui.status(msg % (ct, hint))
+                        ui.status(msg % (ui.label(ct, b'topic.active'), hint))
                     else:
                         msg = _(b"active topic '%s' grew its %d first changesets\n%s")
-                        ui.status(msg % (ct, csetcount, hint))
+                        ui.status(msg % (ui.label(ct, b'topic.active'), csetcount, hint))
 
             tr.addpostclose(b'signalcurrenttopicempty', currenttopicempty)
             return tr
@@ -870,7 +862,8 @@ def topics(ui, repo, topic=None, **opts):
 
     if topic:
         if not ct:
-            ui.status(_(b'marked working directory as topic: %s\n') % topic)
+            ui.status(_(b'marked working directory as topic: %s\n')
+                      % ui.label(topic, b'topic.active'))
         return _changecurrenttopic(repo, topic)
 
     ui.pager(b'topics')
@@ -958,8 +951,8 @@ def debugconvertbookmark(ui, repo, **opts):
 
             revnum = repo[node].rev()
             if len(nodetobook[node]) > 1:
-                ui.status(_(b"skipping revision '%d' as it has multiple bookmarks "
-                          b"on it\n") % revnum)
+                ui.status(_(b"skipping revision %d as it has multiple "
+                            b"bookmarks on it\n") % revnum)
                 return
             targetrevs = _findconvertbmarktopic(repo, bookmark)
             if targetrevs:
@@ -971,8 +964,8 @@ def debugconvertbookmark(ui, repo, **opts):
                 if revnum in skipped:
                     continue
                 if len(nodetobook[revnode]) > 1:
-                    ui.status(_(b"skipping '%d' as it has multiple bookmarks on"
-                              b" it\n") % revnum)
+                    ui.status(_(b"skipping revision %d as it has multiple "
+                                b"bookmarks on it\n") % revnum)
                     skipped.append(revnum)
                     continue
                 if bmark == b'@':
@@ -1082,13 +1075,6 @@ def _changetopics(ui, repo, revs, newtopic):
         else:
             fixedextra[constants.extrakey] = newtopic
         fixedextra[constants.changekey] = c.hex()
-        if b'amend_source' in fixedextra:
-            # TODO: right now the commitctx wrapper in
-            # topicrepo overwrites the topic in extra if
-            # amend_source is set to support 'hg commit
-            # --amend'. Support for amend should be adjusted
-            # to not be so invasive.
-            del fixedextra[b'amend_source']
         ui.debug(b'changing topic of %s from %s to %s\n' % (
             c, oldtopic or b'<none>', newtopic or b'<none>'))
         ui.debug(b'fixedextra: %r\n' % fixedextra)
